@@ -68,6 +68,12 @@ pub enum TimeEntries {
 
   #[clap(about = "Stop a time entry")]
   Stop(StopTimeEntry),
+
+  #[clap(about = "Delete time entry")]
+  Delete(DeleteTimeEntry),
+
+  #[clap(about = "Time entry details")]
+  Details(TimeEntryDetails),
 }
 
 #[derive(Parser, Debug)]
@@ -168,6 +174,18 @@ pub struct StopTimeEntry {
   pub tags: Option<Vec<String>>,
 }
 
+#[derive(Parser, Debug)]
+pub struct DeleteTimeEntry {
+  #[clap(long, about = "Id of the time entry")]
+  pub id: u64,
+}
+
+#[derive(Parser, Debug)]
+pub struct TimeEntryDetails {
+  #[clap(long, about = "Id of the time entry")]
+  pub id: u64,
+}
+
 #[derive(Parser, Debug)]
 pub enum Clients {
   #[clap(about = "List all clients (default workspace)")]
